#####################
multicolorfits 
#####################



=====================
Installation
=====================

* With pip:

.. code-block:: shell

    pip install multicolorfits


* Alternatively, can download just the multicolorfits.py to run in standalone mode from the terminal.  You could then add the file location to your local path:

(for .bashrc)

.. code-block:: shell

    export PYTHONPATH=$PYTHONPATH:/path/to/dir/with/mcf/

(for .cshrc)

.. code-block:: shell

    setenv PYTHONPATH ${PYTHONPATH}:/path/to/dir/with/mcf/


=====================
Basic Usage
=====================

.. code-block:: python

    import multicolorfits as mcf
    mcf.mcf_gui()  #This actually runs the viewer

Or, as a standalone script, download and cd to that directory, and type: 

.. code-block:: shell
    
    python multicolorfits.py


=====================
Examples
=====================

See the main examples page on Github:

 `https://github.com/pjcigan/multicolorfits/blob/master/examples.md <https://github.com/pjcigan/multicolorfits/blob/master/examples.md>`_



